==> haskell-cryptohash-conduit-0.1.1-377-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-conduit
version:              0.1.1
visibility:           public
id:                   cryptohash-conduit-0.1.1-GEZk8CX9OcY8eGiDnido7t
key:                  cryptohash-conduit-0.1.1-GEZk8CX9OcY8eGiDnido7t
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cryptohash-conduit
synopsis:             cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.

category:             Cryptography, Conduit
abi:                  824094eb2666b10f72bce4210679041a
exposed:              True
exposed-modules:      Crypto.Hash.Conduit
import-dirs:          /usr/lib/ghc-8.10.1/site-local/cryptohash-conduit-0.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/cryptohash-conduit-0.1.1
hs-libraries:         HScryptohash-conduit-0.1.1-GEZk8CX9OcY8eGiDnido7t
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    conduit-1.3.2-4RoO14yBJ8Z8NEfHk1lisr
    conduit-extra-1.3.5-BmwJMlsDZUYAfAvPUgG8uA
    cryptohash-0.11.9-B1eI9kNNZRJLLblw9lQi5x
    resourcet-1.2.4.2-Hz0qbBhLH5Z2QSAWMqUgsk transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-378-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-conduit
version:              0.1.1
visibility:           public
id:                   cryptohash-conduit-0.1.1-COLVLWR7xEs3iOn2GTz6Yk
key:                  cryptohash-conduit-0.1.1-COLVLWR7xEs3iOn2GTz6Yk
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cryptohash-conduit
synopsis:             cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.

category:             Cryptography, Conduit
abi:                  19591899c98052e499e927a3df920f90
exposed:              True
exposed-modules:      Crypto.Hash.Conduit
import-dirs:          /usr/lib/ghc-8.10.1/site-local/cryptohash-conduit-0.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/cryptohash-conduit-0.1.1
hs-libraries:         HScryptohash-conduit-0.1.1-COLVLWR7xEs3iOn2GTz6Yk
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    conduit-1.3.2-4jFkdj8khGv79njCeoORFP
    conduit-extra-1.3.5-Kcgn0x8xPW22jyH3JpCwYi
    cryptohash-0.11.9-B1eI9kNNZRJLLblw9lQi5x
    resourcet-1.2.4.2-JppPn6jtwB5KcfB3oqfmhc transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
